# PYXIS
This package is a public astrodynamics analysis and simulation sandbox not intended for commercial use.  Further details
on functionality can be found on the [documentation page](https://www.pyxis-docs.com).

## Contributing
When making contributions to the pyxis code repository, please follow these standards as closely as possible:
- Use [black](https://pypi.org/project/black/) to format all python code
- Use [Google Style](https://www.sphinx-doc.org/en/master/usage/extensions/example_google.html) docstrings for code documentation
- Use [PEP484](https://peps.python.org/pep-0484/) type hinting
- Organize classes and methods by purpose (example: adding non-singular orbital elements would be a class NonSingularElements in pyxis>astro>orbit>elements.py)
- Open issues to allow discussion of the appropriate structure when meaningful destinations do not exist

## License
This packages is not intended for commercial use; however, it is not strictly prohibited.  Insead, you may use this package for commercial use
assuming you make any source code publicly available when using this package.
